======
promoe
======


.. image:: https://img.shields.io/pypi/v/promoe.svg
        :target: https://pypi.python.org/pypi/promoe

.. image:: https://img.shields.io/travis/zethson/promoe.svg
        :target: https://travis-ci.org/zethson/promoe

.. image:: https://readthedocs.org/projects/promoe/badge/?version=latest
        :target: https://promoe.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://pyup.io/repos/github/zethson/promoe/shield.svg
     :target: https://pyup.io/repos/github/zethson/promoe/
     :alt: Updates


Protonize selected atoms with the use of MOE and Pymol.


* Free software: GNU General Public License v3
* Documentation: https://promoe.readthedocs.io.

Overview
--------

.. image:: images/overview.png
    :alt: overview of promoe

Features
--------

* Protonize the binding site of a pdb id automatically
* Remove water atoms that are unable to interact with the ligand after protonization
* Extract charges for residues
* Extract all ligand IDs
* Extract all alternative locations
